==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Heimsknir");
define("_BROWSERS","Vefskoarar");
define("_OPERATINGSYS","Strikerfi");
define("_UNKNOWN","ekkt");
define("_OTHER","Anna/ekkt");
define("_MISCSTATS","msir teljarar");
define("_REGUSERS","Skrir notendur:");
define("_ACTIVEAUTHORS","Virkir hfundar:");
define("_STORIESPUBLISHED","Innsendar frttir/sgur:");
define("_SACTIVETOPICS","Virkir efnisflokkar:");
define("_COMMENTSPOSTED","Innsendar athugasemdir:");
define("_SSPECIALSECT","Fjldi greinasva:");
define("_ARTICLESSEC","Fjldi greina:");
define("_LINKSINLINKS","Tenglar  tenglasafni:");
define("_LINKSCAT","Flokkar  tenglasafni:");
define("_NEWSWAITING","Frttir sem ba ess a vera birtar:");
define("_NUKEVERSION","tgfunmer PHP-Nuke:");
define("_SEARCHENGINES","Leitarvlar");
define("_BOTS","Robots/Spiders");
define("_STATS","tlfri");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Heimsknir");
define("_BROWSERS","Vefskoarar");
define("_OPERATINGSYS","Strikerfi");
define("_UNKNOWN","ekkt");
define("_OTHER","Anna/ekkt");
define("_MISCSTATS","msir teljarar");
define("_REGUSERS","Skrir notendur:");
define("_ACTIVEAUTHORS","Virkir hfundar:");
define("_STORIESPUBLISHED","Innsendar frttir/sgur:");
define("_SACTIVETOPICS","Virkir efnisflokkar:");
define("_COMMENTSPOSTED","Innsendar athugasemdir:");
define("_SSPECIALSECT","Fjldi greinasva:");
define("_ARTICLESSEC","Fjldi greina:");
define("_LINKSINLINKS","Tenglar  tenglasafni:");
define("_LINKSCAT","Flokkar  tenglasafni:");
define("_NEWSWAITING","Frttir sem ba ess a vera birtar:");
define("_NUKEVERSION","tgfunmer PHP-Nuke:");
define("_SEARCHENGINES","Leitarvlar");
define("_BOTS","Robots/Spiders");
define("_STATS","tlfri");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
